# LinkedIn_Feed_Bot

Python package in-development that crawls your LinkedIn news feed in order to create a PDF with a weekly summary of your chosen most important topic. It uses Selenium as its workhorse. If you wish to contribute please visit the [Github repository](https://github.com/Martins6/LinkedIn_Feed_Bot).
